@@ -364,7 +364,7 @@ class InputMediaPhoto(InputMedia):
 
     Optional keyword parameters:
 
-    :param caption: Optional. Caption of the photo to be sent, 0-1024 characters
+    :param caption: Optional. Caption of the photo to be sent, 0-1024 characters after entities parsing
     :type  caption: str|unicode
 
     :param parse_mode: Optional. Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption.
@@ -381,12 +381,12 @@ class InputMediaPhoto(InputMedia):
         Parameters:
 
         :param media: File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass "attach://<file_attach_name>" to upload a new one using multipart/form-data under <file_attach_name> name. More info on Sending Files »
-        :type  media: str|unicode|pytgbot.api_types.sendable.files.InputFile
+        :type  media: str|unicode
 
 
         Optional keyword parameters:
 
-        :param caption: Optional. Caption of the photo to be sent, 0-1024 characters
+        :param caption: Optional. Caption of the photo to be sent, 0-1024 characters after entities parsing
         :type  caption: str|unicode
 
         :param parse_mode: Optional. Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption.
@@ -591,7 +591,7 @@ class InputMediaVideo(InputMediaWithThumb):
         # 'media' given by superclass
         if self.thumb is not None:
             if isinstance(self.thumb, InputFile):
-                array['thumb'] = None  # type InputFile
+                array['thumb'] = None  # will be filled later by get_request_data()
             elif isinstance(self.thumb, str):
                 array['thumb'] = u(self.thumb)  # py2: type unicode, py3: type str
             else:
@@ -706,9 +706,9 @@ class InputMediaAnimation(InputMediaWithThumb):
     Optional keyword parameters:
 
     :param thumb: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail‘s width and height should not exceed 90. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can’t be reused and can be only uploaded as a new file, so you can pass “attach://<file_attach_name>” if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More info on Sending Files »
-    :type  thumb: str|unicode|pytgbot.api_types.sendable.files.InputFile
+    :type  thumb: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
-    :param caption: Optional. Caption of the animation to be sent, 0-1024 characters
+    :param caption: Optional. Caption of the animation to be sent, 0-1024 characters after entities parsing
     :type  caption: str|unicode
 
     :param parse_mode: Optional. Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption.
@@ -739,10 +739,10 @@ class InputMediaAnimation(InputMediaWithThumb):
 
         Optional keyword parameters:
 
-        :param thumb: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail‘s width and height should not exceed 90. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can’t be reused and can be only uploaded as a new file, so you can pass “attach://<file_attach_name>” if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More info on Sending Files »
-        :type  thumb: str|unicode|pytgbot.api_types.sendable.files.InputFile
+        :param thumb: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file, so you can pass "attach://<file_attach_name>" if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More info on Sending Files »
+        :type  thumb: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
-        :param caption: Optional. Caption of the animation to be sent, 0-1024 characters
+        :param caption: Optional. Caption of the animation to be sent, 0-1024 characters after entities parsing
         :type  caption: str|unicode
 
         :param parse_mode: Optional. Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption.
@@ -898,10 +898,10 @@ class InputMediaAudio(InputMediaWithThumb):
 
     Optional keyword parameters:
 
-    :param thumb: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail‘s width and height should not exceed 90. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can’t be reused and can be only uploaded as a new file, so you can pass “attach://<file_attach_name>” if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More info on Sending Files »
-    :type  thumb: str|unicode|pytgbot.api_types.sendable.files.InputFile
+    :param thumb: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file, so you can pass "attach://<file_attach_name>" if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More info on Sending Files »
+    :type  thumb: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
-    :param caption: Optional. Caption of the audio to be sent, 0-1024 characters
+    :param caption: Optional. Caption of the audio to be sent, 0-1024 characters after entities parsing
     :type  caption: str|unicode
 
     :param parse_mode: Optional. Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption.
@@ -932,10 +932,10 @@ class InputMediaAudio(InputMediaWithThumb):
 
         Optional keyword parameters:
 
-        :param thumb: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail‘s width and height should not exceed 90. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can’t be reused and can be only uploaded as a new file, so you can pass “attach://<file_attach_name>” if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More info on Sending Files »
-        :type  thumb: str|unicode|pytgbot.api_types.sendable.files.InputFile
+        :param thumb: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file, so you can pass "attach://<file_attach_name>" if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More info on Sending Files »
+        :type  thumb: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
-        :param caption: Optional. Caption of the audio to be sent, 0-1024 characters
+        :param caption: Optional. Caption of the audio to be sent, 0-1024 characters after entities parsing
         :type  caption: str|unicode
 
         :param parse_mode: Optional. Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption.
@@ -981,7 +981,7 @@ class InputMediaAudio(InputMediaWithThumb):
         # 'media' given by superclass
         if self.thumb is not None:
             if isinstance(self.thumb, InputFile):
-                array['thumb'] = None  # type InputFile
+                array['thumb'] = None   # will be filled later by get_request_data()
             elif isinstance(self.thumb, str):
                 array['thumb'] = u(self.thumb)  # py2: type unicode, py3: type str
             else:
@@ -1117,10 +1117,10 @@ class InputMediaDocument(InputMediaWithThumb):
 
         Optional keyword parameters:
 
-        :param thumb: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail‘s width and height should not exceed 90. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can’t be reused and can be only uploaded as a new file, so you can pass “attach://<file_attach_name>” if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More info on Sending Files »
-        :type  thumb: str|unicode|pytgbot.api_types.sendable.files.InputFile
+        :param thumb: Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file, so you can pass "attach://<file_attach_name>" if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More info on Sending Files »
+        :type  thumb: pytgbot.api_types.sendable.files.InputFile | str|unicode
 
-        :param caption: Optional. Caption of the document to be sent, 0-200 characters
+        :param caption: Optional. Caption of the document to be sent, 0-1024 characters after entities parsing
         :type  caption: str|unicode
 
         :param parse_mode: Optional. Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption.
@@ -1146,7 +1146,7 @@ class InputMediaDocument(InputMediaWithThumb):
         # 'media' given by superclass
         if self.thumb is not None:
             if isinstance(self.thumb, InputFile):
-                array['thumb'] = None  # type InputFile
+                array['thumb'] = None  # will be filled later by get_request_data()
             elif isinstance(self.thumb, str):
                 array['thumb'] = u(self.thumb)  # py2: type unicode, py3: type str
             else:
